# gtodo

Command line todo interface using pure python and click framework for easy track of your future progress.

## Instalation

Recommended way is to use [pip](https://pypi.org/) for installation.

```bash
pip install gtodo
```
## Usage

Refer to help page `gtodo --help`

## Contributing

Pull requests are welcome. This is a very primitive project and everyone with basic python and click knowlege can use this project to train way of open source and github. Please, before pull requesting a major change open an issue first. Every new feature should have appropiate help messege.

## License

[MIT](LICENSE)

## Click project

[Click](https://github.com/pallets/click)
